==> maDB_1.4.0.tar.gz: maDB/man/getExpValue.Rd <==
\name{getEDB}
\alias{getEDB}
\title{Retrieving expression values from a database.}
\description{
  \code{getEDB} this function reads the expression values from the specified signal channels out of a PostgreSQL database. Micro array experiments can be stored into a PostgreSQL database using the \code{publishToDB} method of the \code{EexprSet} object.
}
\usage{
getEDB(con,ids,signal.channels.pk,column.names=c("array_name","color"),v=TRUE)
}
\arguments{
  \item{con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package \pkg{RdbiPgSQL})}
  \item{ids}{The IDs of the genes from which the expression values should be retrieved. In the case of Affymetrix GeneChips the Affymetrix IDs should be used (as they are used as rownames in the \code{exprs} matrix in the \code{exprSet} objects).}
  \item{signal.channels.pk}{the primary keys of the signal channels in the database from which the expression values should be retrieved. To get information about primary keys, arrays... from the database use the \code{dbGetExperimentInfo} function.}
  \item{column.names}{The information that should be used as column names of the expression values matrix. Allowed are all column names of the sample database table.}
  \item{v}{If TRUE additional information will be printed to the console.}
}
\details{
This function is useful, if one wants to get only a subset of genes from a subset of signal channels of one micro array experiment out of the database. Alternative functions are the \code{loadFromDB} method of the \code{EexprSet} class, or use the \code{dbSendQuery} function of the \pkg{RdbiPgSQL} package in combination with SQL.
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{publishToDB}}
    \code{\link{dbGetExperimentInfo}}
    \code{\link{dbConnect}}
    \code{\link{loadFromDB}}
    \code{\link{getMDB}}
}

\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/getExpValue.Rd <==
\name{getEDB}
\alias{getEDB}
\title{Retrieving expression values from a database.}
\description{
  \code{getEDB} this function reads the expression values from the specified signal channels out of a PostgreSQL database. Micro array experiments can be stored into a PostgreSQL database using the \code{publishToDB} method of the \code{EexprSet} object.
}
\usage{
getEDB(con,ids,signal.channels.pk,column.names=c("array_name","color"),v=TRUE)
}
\arguments{
  \item{con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package \pkg{RdbiPgSQL})}
  \item{ids}{The IDs of the genes from which the expression values should be retrieved. In the case of Affymetrix GeneChips the Affymetrix IDs should be used (as they are used as rownames in the \code{exprs} matrix in the \code{exprSet} objects).}
  \item{signal.channels.pk}{the primary keys of the signal channels in the database from which the expression values should be retrieved. To get information about primary keys, arrays... from the database use the \code{dbGetExperimentInfo} function.}
  \item{column.names}{The information that should be used as column names of the expression values matrix. Allowed are all column names of the sample database table.}
  \item{v}{If TRUE additional information will be printed to the console.}
}
\details{
This function is useful, if one wants to get only a subset of genes from a subset of signal channels of one micro array experiment out of the database. Alternative functions are the \code{loadFromDB} method of the \code{EexprSet} class, or use the \code{dbSendQuery} function of the \pkg{RdbiPgSQL} package in combination with SQL.
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{publishToDB}}
    \code{\link{dbGetExperimentInfo}}
%    \code{\link{dbConnect}}
    \code{\link{loadFromDB}}
    \code{\link{getMDB}}
}

\keyword{data}
